@@ -342,7 +342,7 @@ class MutationRoot:
         stored_notifications_arg = parse_arg(
             "storedNotifications", stored_notifications)
         res = self.client.mutation('mutation{createThing(%s%s%s%s){id}}' % (
-            type_arg, firmware_arg, battery_threshold_arg, stored_notifications_arg))["createThing"]
+            type_arg, firmware_arg, stored_notifications_arg))["createThing"]
 
         # FIXME: if we choose to keep the createThingPayload implement it here
         def wrapper(id):
